pub struct IBOStore {
pub store: Vec<u8>,
pub changed: bool,
pub store_pos: Range<usize>,
}Expand description
BufferStore is Storage used to hold and modify the byte arrays that get sent to the GPU.
Fields
store: Vec<u8>Storage used for Vertex or Indicies.
changed: boolBoolean used to deturmine if it got changed to tell the system if we need to reupload the data to the gpu.
store_pos: Range<usize>Location Range within GPU this is Stored At if this does not match the current location internally we will resend the data to the gpu at the new location.
Implementations