pub struct MapRenderer {
pub buffer: InstanceBuffer<TileVertex>,
pub unused_indexs: VecDeque<usize>,
/* private fields */
}Expand description
Instance Buffer Setup for Map’s.
Fields
buffer: InstanceBuffer<TileVertex>Instance Buffer holding all Rendering information for Map’s.
unused_indexs: VecDeque<usize>Stores each unused buffer ID to be pulled into a map_index_buffer for the map ID.
Implementations
Sourceimpl MapRenderer
impl MapRenderer
Sourcepub fn new(
renderer: &mut GpuRenderer,
map_count: u32,
) -> Result<Self, GraphicsError>
pub fn new( renderer: &mut GpuRenderer, map_count: u32, ) -> Result<Self, GraphicsError>
Creates a new MapRenderer.
Arguments
- map_count: The number of Maps to presize the instance buffer by.
Sourcepub fn add_buffer_store(
&mut self,
renderer: &GpuRenderer,
index: OrderedIndex,
buffer_layer: usize,
)
pub fn add_buffer_store( &mut self, renderer: &GpuRenderer, index: OrderedIndex, buffer_layer: usize, )
Adds a Buffer OrderedIndex to the Rendering Store to get processed.
This must be done before MapRenderer::finalize but after Map::update in order for it to Render.
Arguments
- index: The
OrderedIndexof the Object we want to render. - buffer_layer: The Buffer Layer we want to add this Object too.
Sourcepub fn finalize(&mut self, renderer: &mut GpuRenderer)
pub fn finalize(&mut self, renderer: &mut GpuRenderer)
Finalizes the Buffer by processing staged OrderedIndex’s and uploading it to the GPU.
Must be called after all the MapRenderer::add_buffer_store’s.
Sourcepub fn update(
&mut self,
map: &mut Map,
renderer: &mut GpuRenderer,
atlas: &mut AtlasSet,
buffer_layers: [usize; 2],
)
pub fn update( &mut self, map: &mut Map, renderer: &mut GpuRenderer, atlas: &mut AtlasSet, buffer_layers: [usize; 2], )
Updates a Map and adds its OrderedIndex’s to staging using MapRenderer::add_buffer_store.
This must be done before MapRenderer::finalize in order for it to Render.
Arguments
Sourcepub fn bind_group(&self) -> &BindGroup
pub fn bind_group(&self) -> &BindGroup
Returns a reference too wgpu::BindGroup.